@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -17,7 +17,7 @@ from gi.repository import Gio, GLib
 
 LOLLYPOP_DATA_PATH = GLib.get_user_data_dir() + "/lollypop"
 
-Lp = Gio.Application.get_default
+App = Gio.Application.get_default
 
 GOOGLE_API_ID = "015987506728554693370:waw3yqru59a"
 
@@ -37,12 +37,6 @@ class OpenLink:
     NEW = 2
 
 
-# Represent playback context
-class PlayContext:
-    genre_ids = {}
-    artist_ids = {}
-
-
 class GstPlayFlags:
     GST_PLAY_FLAG_VIDEO = 1 << 0  # We want video output
     GST_PLAY_FLAG_AUDIO = 1 << 1  # We want audio output
@@ -57,6 +51,12 @@ class Loading:
     STOP = 4
 
 
+class ResponsiveType:
+    FIXED = 0
+    DND = 1
+    SEARCH = 2
+
+
 class ArtSize:
     NONE = 0
     SMALL = 33
