@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -12,7 +12,7 @@
 
 from gi.repository import GObject
 
-from lollypop.define import PlayContext, Lp, NextContext
+from lollypop.define import App, NextContext
 from lollypop.objects import Track
 
 
@@ -55,18 +55,17 @@ class BasePlayer(GObject.GObject):
             # Keep track of artist/album finished
             self._next_context = NextContext.NONE
             # A user playlist used as current playlist
-            self._user_playlist_ids = []
-            self._user_playlist = []
+            self._playlist_ids = []
+            self._playlist_track_ids = []
             # Used by shuffle tracks to restore user playlist before shuffle
-            self._user_playlist_backup = None
+            self._playlist_backup = None
             self._current_track = Track()
             self._next_track = Track()
             self._prev_track = Track()
-            self._context = PlayContext()
             # Albums in current playlist
             self._albums = []
             # Current shuffle mode
-            self._shuffle = Lp().settings.get_enum("shuffle")
+            self._shuffle = App().settings.get_enum("shuffle")
             # For tracks from the cmd line
             self._external_tracks = []
 
