@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -15,7 +15,7 @@ from gi.repository import Gtk, GLib
 from gettext import gettext as _
 
 from lollypop.objects import Track
-from lollypop.define import Lp, Type
+from lollypop.define import App, Type
 from lollypop.helper_dbus import DBusHelper
 
 
@@ -32,6 +32,7 @@ class RatingWidget(Gtk.Bin):
         """
         Gtk.Bin.__init__(self)
         self.__object = object
+        self.set_property("valign", Gtk.Align.CENTER)
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/RatingWidget.ui")
         builder.connect_signals(self)
@@ -42,7 +43,7 @@ class RatingWidget(Gtk.Bin):
         self._stars.append(builder.get_object("star2"))
         self._stars.append(builder.get_object("star3"))
         self._stars.append(builder.get_object("star4"))
-        self._on_leave_notify(None, None)
+        self._on_leave_notify_event(None, None)
         self.add(builder.get_object("widget"))
         if isinstance(object, Track):
             play_count = object.popularity
@@ -51,9 +52,9 @@ class RatingWidget(Gtk.Bin):
 #######################
 # PROTECTED           #
 #######################
-    def _on_enter_notify(self, widget, event):
+    def _on_enter_notify_event(self, widget, event):
         """
-            On enter notify, change star opacity
+            Update star opacity
             @param widget as Gtk.EventBox
             @param event as Gdk.Event
         """
@@ -73,9 +74,9 @@ class RatingWidget(Gtk.Bin):
             if star == event_star:
                 found = True
 
-    def _on_leave_notify(self, widget, event):
+    def _on_leave_notify_event(self, widget, event):
         """
-            On leave notify, change star opacity
+            Update star opacity
             @param widget as Gtk.EventBox (can be None)
             @param event as Gdk.Event (can be None)
         """
@@ -104,13 +105,13 @@ class RatingWidget(Gtk.Bin):
                 self._stars[idx].set_opacity(0.2)
                 self._stars[idx].get_style_context().remove_class("selected")
 
-    def _on_button_press(self, widget, event):
+    def _on_button_release_event(self, widget, event):
         """
-            On button press, set album popularity
+            Set album popularity
             @param widget as Gtk.EventBox
             @param event as Gdk.Event
         """
-        if Lp().scanner.is_locked():
+        if App().scanner.is_locked():
             return
         user_rating = True
         rate = self.__object.get_rate()
@@ -132,16 +133,17 @@ class RatingWidget(Gtk.Bin):
                 self.__object.set_rate(Type.NONE)
             else:
                 self.__object.set_popularity(0)
-            self._on_leave_notify(None, None)
+            self._on_leave_notify_event(None, None)
         else:
             self.__object.set_rate(pop)
 
         # Save to tags if needed
-        if Lp().settings.get_value("save-to-tags") and\
+        if App().settings.get_value("save-to-tags") and\
                 isinstance(self.__object, Track) and\
                 self.__object.id >= 0:
             dbus_helper = DBusHelper()
-            dbus_helper.call("CanSetCover", None, self.__on_can_set_cover, pop)
+            dbus_helper.call("CanSetCover", None,
+                             self.__on_can_set_popularity, pop)
         return True
 
 #######################
@@ -156,33 +158,32 @@ class RatingWidget(Gtk.Bin):
         star = min(5, int(rate))
         return star
 
-    def __on_can_set_cover(self, source, result, pop):
+    def __on_can_set_popularity(self, source, result, pop):
         """
-            Remove album image from tags
+            Set popularity as kid3 is installed
             @param source as GObject.Object
             @param result as Gio.AsyncResult
             @param pop as int
         """
         try:
             can_set_cover = source.call_finish(result)
-        except:
-            can_set_cover = False
-        if can_set_cover:
-            if pop == 0:
-                value = 0
-            elif pop == 1:
-                value = 1
-            elif pop == 2:
-                value = 64
-            elif pop == 3:
-                value = 128
-            elif pop == 4:
-                value = 196
-            else:
-                value = 255
-            path = GLib.filename_from_uri(self.__object.uri)[0]
-            dbus_helper = DBusHelper()
-            dbus_helper.call("SetPopularity",
-                             GLib.Variant("(is)", (value, path)),
-                             None, None)
-        return True
+            if can_set_cover:
+                if pop == 0:
+                    value = 0
+                elif pop == 1:
+                    value = 1
+                elif pop == 2:
+                    value = 64
+                elif pop == 3:
+                    value = 128
+                elif pop == 4:
+                    value = 196
+                else:
+                    value = 255
+                path = GLib.filename_from_uri(self.__object.uri)[0]
+                dbus_helper = DBusHelper()
+                dbus_helper.call("SetPopularity",
+                                 GLib.Variant("(is)", (value, path)),
+                                 None, None)
+        except Exception as e:
+            print("RatingWidget::__on_can_set_popularity():", e)
